@@ -4,6 +4,7 @@ import datetime
 import functools
 import logging
 from .. import configuration
+import copy
 
 
 logger = logging.getLogger(__name__)
@@ -130,6 +131,10 @@ class ThreeCommasDict(dict):
             return
         super().__init__(*args, **kwargs)
 
+    @classmethod
+    def deepcopy(cls, copy_from: dict):
+        return cls(copy.deepcopy(copy_from))
+
     @classmethod
     def of_list(cls, list_of_d: List[dict]) -> List[cls]:
         if list_of_d is None:
